#!/bin/bash

GREP="/bin/grep"
LS="/bin/ls"

BTFLASH="/bin/btflash.sh"
BACKUPCFGS="/home/httpd/jbmconfig/bin/backupcfgs.sh"
PREPFS="/home/httpd/jbmconfig/bin/prepfs.sh"

findboot () {
    if [ -f "/tmp/bootfs.jffs2" ]; then
        BOOTFS="/tmp/bootfs.jffs2"
    elif [ -f "/tmp/sn-bootfs.jffs2" ]; then
        BOOTFS="/tmp/sn-bootfs.jffs2"
    elif [ -f "/storage/bootfs.jffs2" ]; then
        BOOTFS="/storage/bootfs.jffs2"
    elif [ -f "/storage/sn-bootfs.jffs2" ]; then
        BOOTFS="/storage/sn-bootfs.jffs2"
    else
        echo "No bootfs file found. Please copy bootfs.jffs2 to /tmp"
        return 1
    fi
    echo "Found bootfs file:"
    echo "   $BOOTFS"
    return 0
}

findroot () {
    if [ -f "/tmp/rootfs.jffs2" ]; then
        ROOTFS="/tmp/rootfs.jffs2"
    elif [ -f "/tmp/sn-rootfs.jffs2" ]; then
        ROOTFS="/tmp/sn-rootfs.jffs2"
    else
        echo "No rootfs file found. Please copy rootfs.jffs2 to /tmp"
        return 1
    fi
    echo "Found rootfs file:"
    echo "   $ROOTFS"
    return 0
}

findboot
findroot

if [[ ! -f $BOOTFS || ! -f $ROOTFS ]]; then
    echo ""
    echo "Missing image files. Aborting reflash"
    exit 1
fi

echo -n "Do you want to save device configuration? [Y/n]: "
read SAVECFG

case $SAVECFG in
'NO'|'No'|'no'|'N'|'n' )
    ;;
* )
    $BACKUPCFGS
    if [ "0" != $? ]; then
        echo "Backup failed. Aborting reflash."
        exit 1
    fi
    ;;
esac

echo "cliflash: Stopping unnecessary services:"
# Passing GAU to prepfs will preserve contents of /tmp
$PREPFS GAU
echo "cliflash: Handing process off to $BTFLASH"
($BTFLASH -b $BOOTFS -r $ROOTFS -f &>/dev/console) &

exit 0
